==> haskell-tasty-hedgehog-0.2.0.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.2.0.0
id: tasty-hedgehog-0.2.0.0-81yssGsoQ148T4GNbruomO
key: tasty-hedgehog-0.2.0.0-81yssGsoQ148T4GNbruomO
license: BSD3
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
author: Dave Laing
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.Hedgehog
abi: 5c0fa6919f7f224df7d0b1b4dc02a769
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.2.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-hedgehog-0.2.0.0
hs-libraries: HStasty-hedgehog-0.2.0.0-81yssGsoQ148T4GNbruomO
depends:
    base-4.10.1.0 tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt
    hedgehog-0.5.3-KcXcFk57Fd4Ru6khNTHcZ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt=fb5a791b2b60259c4b58e72c51858b5d
             hedgehog-0.5.3-KcXcFk57Fd4Ru6khNTHcZ=aa22f54b6946def34919884792a111b4
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-0.2.0.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 0.2.0.0
id: tasty-hedgehog-0.2.0.0-KbyQdZFML8pEDqnehbudad
key: tasty-hedgehog-0.2.0.0-KbyQdZFML8pEDqnehbudad
license: BSD3
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
homepage: https://github.com/qfpl/tasty-hedghog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the hedgehog testing library with the tasty testing framework.
category: Testing
author: Dave Laing
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.Hedgehog
abi: 94ebf702ce4234e6b996d719303a6f46
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.2.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-hedgehog-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-hedgehog-0.2.0.0
hs-libraries: HStasty-hedgehog-0.2.0.0-KbyQdZFML8pEDqnehbudad
depends:
    base-4.10.1.0 tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt
    hedgehog-0.5.3-LdllZDc4UCiIDWHwYjXMhN
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1.1-G4ET5FMzEAdFZ1yh3S4uTt=fb5a791b2b60259c4b58e72c51858b5d
             hedgehog-0.5.3-LdllZDc4UCiIDWHwYjXMhN=6b1d762a59057d24d9c26598fb4a58a5
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
